import glob
import numpy as np
import cv2
import matplotlib.pyplot as plt
import seaborn as sns
import pandas as pd
import os
import re
from scipy import signal


if __name__ == "__main__":
    minimum_cdk_peak = {"HS001": 1.7, "HS115": 1.9, "HS189": 1.7, "HS360": 1.7, "HS007": 1.7}      # ピークと検出されるために最低限必要なratio値
    cmap = sns.color_palette()
    cmap_hm = "plasma"

    strains_to_omit = ["HS188"]

    data_tot_hm = pd.read_csv("./_total_time-course.csv", index_col=0)
    data_div_to_div = pd.read_csv("./_div_to_div.csv", index_col=0)
    data_stats = pd.read_csv("./_stats.csv", index_col=0)

    strains = sorted(data_tot_hm["strain"].unique().tolist())  # strainを重複なく抜き出す
    for cmp in strains_to_omit:
        if cmp in strains:
            strains.remove(cmp)     # plotに使いたくないやつを除く

    # heatmapで全データをプロット．2回目の分裂でアラインされている．
    hm_length = 450
    for k in range(len(strains)):
        data_plot_heatmap = pd.DataFrame({})
        data_plot_heatmap_RFP = pd.DataFrame({})

        strain = strains[k]
        data_temp = data_tot_hm.loc[data_tot_hm["strain"] == strain, ["time", "CDKEV-raw", "cdc13-raw", "first-duration", "cell"]]
        first_durations = sorted(data_temp["first-duration"].unique().tolist())  # first-durationを重複なく抜き出す
        data_plot_heatmap["cell-0000"] = [np.NaN for k in range(hm_length)]
        data_plot_heatmap_RFP["cell-0000"] = [np.NaN for k in range(hm_length)]
        for cmp in first_durations:
            cells_to_plot = data_temp.loc[(data_temp["first-duration"] == cmp), "cell"].unique().tolist()
            for cell in cells_to_plot:
                temp = data_temp.loc[data_temp["cell"] == cell]["CDKEV-raw"].astype("float64")
                data_plot_heatmap["cell-" + str(cell)] = temp
                temp_RFP = data_temp.loc[data_temp["cell"] == cell]["cdc13-raw"].astype("float64")
                data_plot_heatmap_RFP["cell-" + str(cell)] = temp_RFP

    fig = plt.figure(figsize=(8, 6))
    data_temp = data_stats.copy()
    for strain_to_omit in strains_to_omit:
        data_temp = data_temp.loc[data_temp["strain"] != strain_to_omit]
    sns.violinplot(x="strain", y="cdk-at-div", data=data_temp, color="lightgray", jitter=False)
    sns.swarmplot(x="strain", y="cdk-at-div", data=data_temp, hue="strain")
    plt.savefig("./__cdk_distribution.png")
    plt.close(fig)
    print(data_temp.groupby("strain").mean()["cdk-at-div"], data_temp.groupby("strain").std()["cdk-at-div"])
    print(data_temp.groupby("strain").mean()["cell-cycle-length"], data_temp.groupby("strain").std()["cell-cycle-length"])

